@@ -9,15 +9,15 @@ See http://betamax.rtfd.org/ for documentation.
 
 """
 
-from betamax.exceptions import BetamaxError
-from betamax.recorder import Betamax
-from betamax.matchers import BaseMatcher
-from betamax.serializers import BaseSerializer
+from .exceptions import BetamaxError
+from .recorder import Betamax
+from .matchers import BaseMatcher
+from .serializers import BaseSerializer
 
 __all__ = [BetamaxError, Betamax, BaseMatcher, BaseSerializer]
 __author__ = 'Ian Cordasco'
 __copyright__ = 'Copyright 2013 Ian Cordasco'
 __license__ = 'Apache 2.0'
 __title__ = 'betamax'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
